# coding: utf-8

"""
    Mentortools Public API

    Mentortools public API service

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from public_api_server_connector.models.module_lesson_patch import ModuleLessonPatch  # noqa: E501

class TestModuleLessonPatch(unittest.TestCase):
    """ModuleLessonPatch unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ModuleLessonPatch:
        """Test ModuleLessonPatch
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ModuleLessonPatch`
        """
        model = ModuleLessonPatch()  # noqa: E501
        if include_optional:
            return ModuleLessonPatch(
                submodule_id = 56,
                thread_id = 56,
                image_id = '',
                order = 56,
                title = '',
                payload = '',
                is_active = True,
                is_published = True,
                mandatory = True
            )
        else:
            return ModuleLessonPatch(
        )
        """

    def testModuleLessonPatch(self):
        """Test ModuleLessonPatch"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
